==> haskell-either-4.4.1.1-25-i686.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1.1
id: either-4.4.1.1-6ucIi2pNmQoDvbqY3CvdDk
key: either-4.4.1.1-6ucIi2pNmQoDvbqY3CvdDk
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
abi: 1c857ffccbc29ed170764825d69f049f
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/either-4.4.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/either-4.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/either-4.4.1.1
hs-libraries: HSeither-4.4.1.1-6ucIi2pNmQoDvbqY3CvdDk
depends:
    MonadRandom-0.5.1-4pilVmquiIE6YjsysdbKdo base-4.9.1.0
    bifunctors-5.4.2-8sihn7PNvccAEMEjqQmBaw
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    free-4.12.4-FW8PJ0KjF1a9R2T6o2HFwI
    mmorph-1.1.0-BKb9vDVN1ubG7npUIlJCzH
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    profunctors-5.2-8AU42QqEa6oClTRTu9iu4K
    semigroupoids-5.2-I9hFsiKk7FC4Vp6kTTs0M3
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-4.4.1.1-27-i686.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 4.4.1.1
id: either-4.4.1.1-ILupdecl1293Cc0SGnn407
key: either-4.4.1.1-ILupdecl1293Cc0SGnn407
license: BSD3
copyright: Copyright (C) 2008-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: An either monad transformer
description:
    An either monad transformer
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Monad.Trans.Either Data.Either.Combinators
    Data.Either.Validation
abi: bb8c436ccd984ca8e3452ad9729dff84
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/either-4.4.1.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/either-4.4.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/either-4.4.1.1
hs-libraries: HSeither-4.4.1.1-ILupdecl1293Cc0SGnn407
depends:
    MonadRandom-0.5.1-4pilVmquiIE6YjsysdbKdo base-4.9.1.0
    bifunctors-5.4.2-8sihn7PNvccAEMEjqQmBaw
    exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    free-4.12.4-3GdOADSpSgmCdK4GoN8xLg
    mmorph-1.1.0-BKb9vDVN1ubG7npUIlJCzH
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    profunctors-5.2.1-5x71Wug1TnuAdpWqS2CUNd
    semigroupoids-5.2.1-AZdsYazgWLZ9acFdqW12To
    semigroups-0.18.3-5xL9BgkWQsCGwo6YahyMCM transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
